componenttools.copy_components_and_remove_all_spanners
======================================================

.. autofunction:: abjad.tools.componenttools.copy_components_and_remove_all_spanners.copy_components_and_remove_all_spanners
